 linecounter
======================

linecounter is a tool written in python, you can count how many lines you have in your files. This tool may be useful for developers who want to count how many lines of code they have in their projects. Because of linecounter isn't restricted for just code files it can be used in many areas which needs line counting. 

 Features
======================
- Line counting for given file/files
- Line counting for list of files in given directory
- Line counting for list of files in given directory recursively
- Line counting for list of files in given directory with filtering file extensions
